@@ -284,12 +284,12 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	/////////////////////////////////////////////////////
 	int i;
 
-	__SSE_DATATYPE a1_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*5]);
-	__SSE_DATATYPE a2_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*4]);
-	__SSE_DATATYPE a3_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*3]);
-	__SSE_DATATYPE a4_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*2]);
-	__SSE_DATATYPE a5_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq]);
-	__SSE_DATATYPE a6_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[0]);
+	__SSE_DATATYPE a1_1 = _SSE_LOAD(0,  &q[ldq*5]);
+	__SSE_DATATYPE a2_1 = _SSE_LOAD(0,  &q[ldq*4]);
+	__SSE_DATATYPE a3_1 = _SSE_LOAD(0,  &q[ldq*3]);
+	__SSE_DATATYPE a4_1 = _SSE_LOAD(0,  &q[ldq*2]);
+	__SSE_DATATYPE a5_1 = _SSE_LOAD(0,  &q[ldq]);
+	__SSE_DATATYPE a6_1 = _SSE_LOAD(0,  &q[0]);
 
 #ifdef DOUBLE_PRECISION_REAL
 	__SSE_DATATYPE h_6_5 = vec_splats(hh[(ldh*5)+1]);
@@ -363,12 +363,12 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 
 	register __SSE_DATATYPE x1 = a1_1;
 
-	__SSE_DATATYPE a1_2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*5)+offset]);
-	__SSE_DATATYPE a2_2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*4)+offset]);
-	__SSE_DATATYPE a3_2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*3)+offset]);
-	__SSE_DATATYPE a4_2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*2)+offset]);
-	__SSE_DATATYPE a5_2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq)+offset]);
-	__SSE_DATATYPE a6_2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[offset]);
+	__SSE_DATATYPE a1_2 = _SSE_LOAD(0,  &q[(ldq*5)+offset]);
+	__SSE_DATATYPE a2_2 = _SSE_LOAD(0,  &q[(ldq*4)+offset]);
+	__SSE_DATATYPE a3_2 = _SSE_LOAD(0,  &q[(ldq*3)+offset]);
+	__SSE_DATATYPE a4_2 = _SSE_LOAD(0,  &q[(ldq*2)+offset]);
+	__SSE_DATATYPE a5_2 = _SSE_LOAD(0,  &q[(ldq)+offset]);
+	__SSE_DATATYPE a6_2 = _SSE_LOAD(0,  &q[offset]);
 
 	register __SSE_DATATYPE t2 = _SSE_ADD(a6_2, _SSE_MUL(a5_2, h_6_5));
 	t2 = _SSE_ADD(t2, _SSE_MUL(a4_2, h_6_4));
@@ -406,8 +406,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 #ifdef SINGLE_PRECISION_REAL
 		h1 = vec_splats(hh[i-5] );
 #endif
-		q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[i*ldq]);
-		q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(i*ldq)+offset]);
+		q1 = _SSE_LOAD(0,  &q[i*ldq]);
+		q2 = _SSE_LOAD(0,  &q[(i*ldq)+offset]);
 
 		x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 		x2 = _SSE_ADD(x2, _SSE_MUL(q2,h1));
@@ -464,8 +464,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 #ifdef SINGLE_PRECISION_REAL
 	h1 = vec_splats(hh[nb-5] );
 #endif
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[nb*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[nb*ldq]);
+	q2 = _SSE_LOAD(0,  &q[(nb*ldq)+offset]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 	x2 = _SSE_ADD(x2, _SSE_MUL(q2,h1));
@@ -513,8 +513,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 #ifdef SINGLE_PRECISION_REAL
 	h1 = vec_splats(hh[nb-4] );
 #endif
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+1)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+1)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+1)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+1)*ldq)+offset]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 	x2 = _SSE_ADD(x2, _SSE_MUL(q2,h1));
@@ -556,8 +556,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-3] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+2)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+2)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+2)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+2)*ldq)+offset]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 	x2 = _SSE_ADD(x2, _SSE_MUL(q2,h1));
@@ -589,8 +589,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-2] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+3)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+3)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+3)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+3)*ldq)+offset]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 	x2 = _SSE_ADD(x2, _SSE_MUL(q2,h1));
@@ -613,8 +613,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-1] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+4)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+4)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+4)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+4)*ldq)+offset]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 	x2 = _SSE_ADD(x2, _SSE_MUL(q2,h1));
@@ -751,8 +751,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	// Rank-1 update of Q [4 x nb+3]
 	/////////////////////////////////////////////////////
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[0]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[offset]);
+	q1 = _SSE_LOAD(0,  &q[0]);
+	q2 = _SSE_LOAD(0,  &q[offset]);
 	q1 = _SSE_SUB(q1, t1);
 	q2 = _SSE_SUB(q2, t2);
 	_SSE_STORE((__vector unsigned int) q1, 0, (unsigned int *) &q[0]);
@@ -767,8 +767,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 #endif
 
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq+offset)]);
+	q1 = _SSE_LOAD(0,  &q[ldq]);
+	q2 = _SSE_LOAD(0,  &q[(ldq+offset)]);
 	q1 = _SSE_SUB(q1, v1);
 	q2 = _SSE_SUB(q2, v2);
 
@@ -776,7 +776,7 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	q2 = _SSE_SUB(q2, _SSE_MUL(t2, h6));
 
 	_SSE_STORE((__vector unsigned int), 0, (unsigned int *) &q[ldq]);
-	_SSE_STORE((__vector unsingen int), 0, (unsinged int *) &q[(ldq+offset)]);
+	_SSE_STORE((__vector unsigned int), 0, (unsigned int *) &q[(ldq+offset)]);
 
 #ifdef DOUBLE_PRECISION_REAL
 	h5 = vec_splats(hh[(ldh*4)+1]);
@@ -784,8 +784,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 #ifdef SINGLE_PRECISION_REAL
 	h5 = vec_splats(hh[(ldh*4)+1] );
 #endif
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*2]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*2)+offset]);
+	q1 = _SSE_LOAD(0,  &q[ldq*2]);
+	q2 = _SSE_LOAD(0,  &q[(ldq*2)+offset]);
 	q1 = _SSE_SUB(q1, w1);
 	q2 = _SSE_SUB(q2, w2);
 	q1 = _SSE_SUB(q1, _SSE_MUL(v1, h5));
@@ -811,8 +811,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h4 = vec_splats(hh[(ldh*3)+1] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*3]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*3)+offset]);
+	q1 = _SSE_LOAD(0,  &q[ldq*3]);
+	q2 = _SSE_LOAD(0,  &q[(ldq*3)+offset]);
 	q1 = _SSE_SUB(q1, z1);
 	q2 = _SSE_SUB(q2, z2);
 
@@ -840,7 +840,7 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	q2 = _SSE_SUB(q2, _SSE_MUL(t2, h6));
 
 	_SSE_STORE((__vector unsigned int) q1, 0, (unsigned int *) &q[ldq*3]);
-	_SSE_STORE((__vector unsinged int) q2, 0, (unsigned int *) &q[(ldq*3)+offset]);
+	_SSE_STORE((__vector unsigned int) q2, 0, (unsigned int *) &q[(ldq*3)+offset]);
 
 #ifdef DOUBLE_PRECISION_REAL
 	h3 = vec_splats(hh[(ldh*2)+1]);
@@ -849,8 +849,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h3 = vec_splats(hh[(ldh*2)+1] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*4]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*4)+offset]);
+	q1 = _SSE_LOAD(0,  &q[ldq*4]);
+	q2 = _SSE_LOAD(0,  &q[(ldq*4)+offset]);
 	q1 = _SSE_SUB(q1, y1);
 	q2 = _SSE_SUB(q2, y2);
 
@@ -897,8 +897,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h2 = vec_splats(hh[(ldh)+1] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*5]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(ldq*5)+offset]);
+	q1 = _SSE_LOAD(0,  &q[ldq*5]);
+	q2 = _SSE_LOAD(0,  &q[(ldq*5)+offset]);
 	q1 = _SSE_SUB(q1, x1);
 	q2 = _SSE_SUB(q2, x2);
 
@@ -950,8 +950,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 
 	for (i = 6; i < nb; i++)
 	{
-		q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[i*ldq]);
-		q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(i*ldq)+offset]);
+		q1 = _SSE_LOAD(0,  &q[i*ldq]);
+		q2 = _SSE_LOAD(0,  &q[(i*ldq)+offset]);
 #ifdef DOUBLE_PRECISION_REAL
 		h1 = vec_splats(hh[i-5]);
 #endif
@@ -1023,8 +1023,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-5] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[nb*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[nb*ldq]);
+	q2 = _SSE_LOAD(0,  &q[(nb*ldq)+offset]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 	q2 = _SSE_SUB(q2, _SSE_MUL(x2, h1));
@@ -1079,8 +1079,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-4] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+1)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+1)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+1)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+1)*ldq)+offset]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 	q2 = _SSE_SUB(q2, _SSE_MUL(x2, h1));
@@ -1125,8 +1125,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-3] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+2)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+2)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+2)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+2)*ldq)+offset]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 	q2 = _SSE_SUB(q2, _SSE_MUL(x2, h1));
@@ -1161,8 +1161,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-2] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+3)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+3)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+3)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+3)*ldq)+offset]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 	q2 = _SSE_SUB(q2, _SSE_MUL(x2, h1));
@@ -1187,8 +1187,8 @@ __forceinline void hh_trafo_kernel_8_VSX_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-1] );
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+4)*ldq]);
-	q2 = _SSE_LOAD(0, (unsigned long int *)  0, &q[((nb+4)*ldq)+offset]);
+	q1 = _SSE_LOAD(0,  &q[(nb+4)*ldq]);
+	q2 = _SSE_LOAD(0,  &q[((nb+4)*ldq)+offset]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 	q2 = _SSE_SUB(q2, _SSE_MUL(x2, h1));
@@ -1220,12 +1220,12 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	/////////////////////////////////////////////////////
 	int i;
 
-	__SSE_DATATYPE a1_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*5]);
-	__SSE_DATATYPE a2_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*4]);
-	__SSE_DATATYPE a3_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*3]);
-	__SSE_DATATYPE a4_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*2]);
-	__SSE_DATATYPE a5_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq]);
-	__SSE_DATATYPE a6_1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[0]);
+	__SSE_DATATYPE a1_1 = _SSE_LOAD(0,  &q[ldq*5]);
+	__SSE_DATATYPE a2_1 = _SSE_LOAD(0,  &q[ldq*4]);
+	__SSE_DATATYPE a3_1 = _SSE_LOAD(0,  &q[ldq*3]);
+	__SSE_DATATYPE a4_1 = _SSE_LOAD(0,  &q[ldq*2]);
+	__SSE_DATATYPE a5_1 = _SSE_LOAD(0,  &q[ldq]);
+	__SSE_DATATYPE a6_1 = _SSE_LOAD(0,  &q[0]);
 
 #ifdef DOUBLE_PRECISION_REAL
 	__SSE_DATATYPE h_6_5 = vec_splats(hh[(ldh*5)+1]);
@@ -1314,7 +1314,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 #ifdef SINGLE_PRECISION_REAL
 		h1 = vec_splats(hh[i-5]) ;
 #endif
-		q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[i*ldq]);
+		q1 = _SSE_LOAD(0,  &q[i*ldq]);
 
 		x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 
@@ -1372,7 +1372,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-5]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[nb*ldq]);
+	q1 = _SSE_LOAD(0,  &q[nb*ldq]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 
@@ -1420,7 +1420,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-4]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+1)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+1)*ldq]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 
@@ -1458,7 +1458,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-3]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+2)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+2)*ldq]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 
@@ -1487,7 +1487,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-2]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+3)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+3)*ldq]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 
@@ -1507,7 +1507,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-1]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+4)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+4)*ldq]);
 
 	x1 = _SSE_ADD(x1, _SSE_MUL(q1,h1));
 
@@ -1636,7 +1636,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	// Rank-1 update of Q [2 x nb+3]
 	/////////////////////////////////////////////////////
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[0]);
+	q1 = _SSE_LOAD(0,  &q[0]);
 	q1 = _SSE_SUB(q1, t1);
 	_SSE_STORE((__vector unsigned int) q1, 0, (unsigned int *) &q[0]);
 
@@ -1647,7 +1647,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h6 = vec_splats(hh[(ldh*5)+1]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq]);
+	q1 = _SSE_LOAD(0,  &q[ldq]);
 	q1 = _SSE_SUB(q1, v1);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(t1, h6));
@@ -1660,7 +1660,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 #ifdef SINGLE_PRECISION_REAL
 	h5 = vec_splats(hh[(ldh*4)+1]) ;
 #endif
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*2]);
+	q1 = _SSE_LOAD(0,  &q[ldq*2]);
 	q1 = _SSE_SUB(q1, w1);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(v1, h5));
@@ -1683,7 +1683,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h4 = vec_splats(hh[(ldh*3)+1]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*3]);
+	q1 = _SSE_LOAD(0,  &q[ldq*3]);
 	q1 = _SSE_SUB(q1, z1);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(w1, h4));
@@ -1715,7 +1715,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h3 = vec_splats(hh[(ldh*2)+1]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*4]);
+	q1 = _SSE_LOAD(0,  &q[ldq*4]);
 	q1 = _SSE_SUB(q1, y1);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(z1, h3));
@@ -1756,7 +1756,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h2 = vec_splats(hh[(ldh)+1]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[ldq*5]);
+	q1 = _SSE_LOAD(0,  &q[ldq*5]);
 	q1 = _SSE_SUB(q1, x1);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(y1, h2));
@@ -1801,7 +1801,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 
 	for (i = 6; i < nb; i++)
 	{
-		q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[i*ldq]);
+		q1 = _SSE_LOAD(0,  &q[i*ldq]);
 #ifdef DOUBLE_PRECISION_REAL
 		h1 = vec_splats(hh[i-5]);
 #endif
@@ -1866,7 +1866,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-5]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[nb*ldq]);
+	q1 = _SSE_LOAD(0,  &q[nb*ldq]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 
@@ -1915,7 +1915,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-4]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+1)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+1)*ldq]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 
@@ -1955,7 +1955,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-3]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+2)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+2)*ldq]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 
@@ -1986,7 +1986,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-2]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+3)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+3)*ldq]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 
@@ -2008,7 +2008,7 @@ __forceinline void hh_trafo_kernel_4_SSE_6hv_single(float* q, float* hh, int nb,
 	h1 = vec_splats(hh[nb-1]) ;
 #endif
 
-	q1 = _SSE_LOAD(0, (unsigned long int *)  0, &q[(nb+4)*ldq]);
+	q1 = _SSE_LOAD(0,  &q[(nb+4)*ldq]);
 
 	q1 = _SSE_SUB(q1, _SSE_MUL(x1, h1));
 
