@@ -58,8 +58,14 @@
 #endif
 
 int max_threads_glob;
+int max_threads_glob_1;
 int set_max_threads_glob=0;
+int set_max_threads_glob_1=0;
+#ifdef WITH_AMD_GPU_VERSION
+#define default_max_stored_rows 256
+#else
 int const default_max_stored_rows = 256;   
+#endif
 
 static int enumerate_identity(elpa_index_t index, int i);
 static int cardinality_bool(elpa_index_t index);
@@ -119,8 +125,11 @@ int nvidia_gpu_count();
 #ifdef WITH_AMD_GPU_VERSION
 int amd_gpu_count();
 #endif
-#ifdef WITH_INTEL_GPU_VERSION
-//missing function for GPU count
+#ifdef WITH_SYCL_GPU_VERSION
+int sycl_gpu_count();
+#endif
+#ifdef WITH_OPENMP_OFFLOAD_GPU_VERSION
+int openmp_offload_gpu_count();
 #endif
 
 static int use_gpu_id_cardinality(elpa_index_t index);
@@ -224,9 +233,9 @@ static const elpa_index_int_entry_t int_entries[] = {
         INT_PARAMETER_ENTRY("num_process_cols", "Number of process column number in the 2D domain decomposition", NULL, PRINT_STRUCTURE),
         INT_PARAMETER_ENTRY("num_processes", "Total number of processes", NULL, PRINT_STRUCTURE),
         INT_PARAMETER_ENTRY("bandwidth", "If specified, a band matrix with this bandwidth is expected as input; bandwidth must be multiply of nblk and at least 2", bw_is_valid, PRINT_YES),
-        INT_ANY_ENTRY("mpi_comm_rows", "Communicator for inter-row communication", PRINT_NO),
-        INT_ANY_ENTRY("mpi_comm_cols", "Communicator for inter-column communication", PRINT_NO),
-        INT_ANY_ENTRY("mpi_comm_parent", "Parent communicator", PRINT_NO),
+        INT_PARAMETER_ENTRY("mpi_comm_rows", "Communicator for inter-row communication", NULL, PRINT_NO),
+        INT_PARAMETER_ENTRY("mpi_comm_cols", "Communicator for inter-column communication", NULL, PRINT_NO),
+        INT_PARAMETER_ENTRY("mpi_comm_parent", "Parent communicator", NULL, PRINT_NO),
         INT_ANY_ENTRY("blacs_context", "BLACS context", PRINT_NO),
         INT_ENTRY("verbose", "ELPA API prints verbose messages", 0, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_NONE, \
                         cardinality_bool, enumerate_identity, verbose_is_valid, NULL, PRINT_YES),
@@ -315,6 +324,8 @@ static const elpa_index_int_entry_t int_entries[] = {
                         cardinality_bool, enumerate_identity, amd_gpu_is_valid, NULL, PRINT_YES),
         //default of gpu ussage for individual phases is 1. However, it is only evaluated, if GPU is used at all, which first has to be determined
         //by the parameter gpu and presence of the device
+        INT_ENTRY("gpu_hermitian_multiply", "Use GPU acceleration for elpa_hermitian_multiply", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
+                        cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
         INT_ENTRY("gpu_invert_trm", "Use GPU acceleration for elpa_triangular", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
                         cardinality_bool, enumerate_identity, valid_with_gpu, NULL, PRINT_YES),
         INT_ENTRY("gpu_cholesky", "Use GPU acceleration for elpa_cholesky", 1, ELPA_AUTOTUNE_NOT_TUNABLE, ELPA_AUTOTUNE_GPU, ELPA_AUTOTUNE_DOMAIN_ANY, ELPA_AUTOTUNE_PART_ANY, \
@@ -857,7 +868,7 @@ static const char *real_kernel_name(int kernel) {
         kernel_number == ELPA_2STAGE_REAL_AMD_GPU ? gpu_is_active : 1
 
 #define REAL_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE(kernel_number) \
-        kernel_number == ELPA_2STAGE_REAL_INTEL_GPU ? gpu_is_active : 1
+        kernel_number == ELPA_2STAGE_REAL_INTEL_GPU_SYCL ? gpu_is_active : 1
 
 static int real_kernel_is_valid(elpa_index_t index, int n, int new_value) {
         int solver = elpa_index_get_int_value(index, "solver", NULL);
@@ -872,10 +883,16 @@ static int real_kernel_is_valid(elpa_index_t index, int n, int new_value) {
 #ifdef WITH_AMD_GPU_VERSION
                 ELPA_FOR_ALL_2STAGE_REAL_KERNELS(VALID_CASE_3, REAL_AMD_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
 #endif
-#ifdef WITH_INTEL_GPU_VERSION
+//#ifdef WITH_INTEL_GPU_VERSION
+//                ELPA_FOR_ALL_2STAGE_REAL_KERNELS(VALID_CASE_3, REAL_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
+//#endif
+#ifdef WITH_OPENMP_OFFLOAD_GPU_VERSION
                 ELPA_FOR_ALL_2STAGE_REAL_KERNELS(VALID_CASE_3, REAL_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
 #endif
-#if !defined(WITH_NVIDIA_GPU_VERSION) && !defined(WITH_AMD_GPU_VERSION) && !defined(WITH_INTEL_GPU_VERSION)
+#ifdef WITH_SYCL_GPU_VERSION
+                ELPA_FOR_ALL_2STAGE_REAL_KERNELS(VALID_CASE_3, REAL_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
+#endif
+#if !defined(WITH_NVIDIA_GPU_VERSION) && !defined(WITH_AMD_GPU_VERSION) && !defined(WITH_OPENMP_OFFLOAD_GPU_VERSION) && !defined(WITH_SYCL_GPU_VERSION)
                 ELPA_FOR_ALL_2STAGE_REAL_KERNELS(VALID_CASE_3, REAL_NVIDIA_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
 #endif
 		// intel missing
@@ -914,7 +931,7 @@ static const char *complex_kernel_name(int kernel) {
         kernel_number == ELPA_2STAGE_COMPLEX_AMD_GPU ? gpu_is_active : 1
 
 #define COMPLEX_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE(kernel_number) \
-        kernel_number == ELPA_2STAGE_COMPLEX_INTEL_GPU ? gpu_is_active : 1
+        kernel_number == ELPA_2STAGE_COMPLEX_INTEL_GPU_SYCL ? gpu_is_active : 1
 
 static int complex_kernel_is_valid(elpa_index_t index, int n, int new_value) {
         int solver = elpa_index_get_int_value(index, "solver", NULL);
@@ -929,10 +946,16 @@ static int complex_kernel_is_valid(elpa_index_t index, int n, int new_value) {
 #ifdef WITH_AMD_GPU_VERSION
                 ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS(VALID_CASE_3, COMPLEX_AMD_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
 #endif
-#ifdef WITH_INTEL_GPU_VERSION
+//#ifdef WITH_INTEL_GPU_VERSION
+//                ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS(VALID_CASE_3, COMPLEX_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
+//#endif
+#ifdef WITH_OPENMP_OFFLOAD_GPU_VERSION
                 ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS(VALID_CASE_3, COMPLEX_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
 #endif
-#if !defined(WITH_NVIDIA_GPU_VERSION) && !defined(WITH_AMD_GPU_VERSION) && !defined(WITH_INTEL_GPU_VERSION)
+#ifdef WITH_SYCL_GPU_VERSION
+                ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS(VALID_CASE_3, COMPLEX_INTEL_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
+#endif
+#if !defined(WITH_NVIDIA_GPU_VERSION) && !defined(WITH_AMD_GPU_VERSION) && !defined(WITH_OPENMP_OFFLOAD_GPU_VERSION) && !defined(WITH_SYCL_GPU_VERSION)
                 ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS(VALID_CASE_3, COMPLEX_NVIDIA_GPU_KERNEL_ONLY_WHEN_GPU_IS_ACTIVE)
 #endif
 		// intel missing
@@ -1012,7 +1035,7 @@ static int amd_gpu_is_valid(elpa_index_t index, int n, int new_value) {
 }
 
 static int intel_gpu_is_valid(elpa_index_t index, int n, int new_value) {
-#ifdef WITH_INTEL_GPU_VERSION
+#if defined(WITH_OPENMP_OFFLOAD_GPU_VERSION) || defined(WITH_SYCL_GPU_VERSION)
         return new_value == 0 || new_value == 1;
 #else
         return new_value == 0;
@@ -1029,7 +1052,7 @@ static int verbose_is_valid(elpa_index_t index, int n, int new_value) {
 
 static int nbc_elpa1_is_valid(elpa_index_t index, int n, int new_value) {
         int solver = elpa_index_get_int_value(index, "solver", NULL);
-        if ((solver == ELPA_SOLVER_1STAGE)) {
+        if (solver == ELPA_SOLVER_1STAGE) {
                 return ((new_value == 0 ) || (new_value == 1));
         }
         else {
@@ -1039,7 +1062,7 @@ static int nbc_elpa1_is_valid(elpa_index_t index, int n, int new_value) {
 
 static int nbc_elpa2_is_valid(elpa_index_t index, int n, int new_value) {
         int solver = elpa_index_get_int_value(index, "solver", NULL);
-        if ((solver == ELPA_SOLVER_2STAGE)) {
+        if (solver == ELPA_SOLVER_2STAGE) {
                 return ((new_value == 0 ) || (new_value == 1));
         }
         else {
@@ -1206,15 +1229,15 @@ static int omp_threads_enumerate(elpa_index_t index, int i) {
 static int omp_threads_is_valid(elpa_index_t index, int n, int new_value) {
         int max_threads;
 #ifdef WITH_OPENMP_TRADITIONAL
-	if (set_max_threads_glob == 0) {
-		max_threads_glob = omp_get_max_threads();
-		set_max_threads_glob = 1;
+	if (set_max_threads_glob_1 == 0) {
+		max_threads_glob_1 = omp_get_max_threads();
+		set_max_threads_glob_1 = 1;
 	}
 #else
-	max_threads_glob = 1;
-	set_max_threads_glob = 1;
+	max_threads_glob_1 = 1;
+	set_max_threads_glob_1 = 1;
 #endif
-	max_threads = max_threads_glob;
+	max_threads = max_threads_glob_1;
         return (1 <= new_value) && (new_value <= max_threads);
 }
 
@@ -1232,7 +1255,7 @@ static int valid_with_gpu(elpa_index_t index, int n, int new_value) {
 static int valid_with_gpu_elpa1(elpa_index_t index, int n, int new_value) {
         int solver = elpa_index_get_int_value(index, "solver", NULL);
         int gpu_is_active = (elpa_index_get_int_value(index, "nvidia-gpu", NULL) || elpa_index_get_int_value(index, "gpu", NULL) || elpa_index_get_int_value(index, "amd-gpu", NULL) || elpa_index_get_int_value(index, "intel-gpu", NULL));
-        if ((solver == ELPA_SOLVER_1STAGE) && (gpu_is_active == 1)) {
+        if ( (solver == ELPA_SOLVER_1STAGE) && (gpu_is_active == 1) ) {
                 return ((new_value == 0 ) || (new_value == 1));
         }
         else {
@@ -1243,7 +1266,7 @@ static int valid_with_gpu_elpa1(elpa_index_t index, int n, int new_value) {
 static int valid_with_gpu_elpa2(elpa_index_t index, int n, int new_value) {
         int solver = elpa_index_get_int_value(index, "solver", NULL);
         int gpu_is_active = (elpa_index_get_int_value(index, "nvidia-gpu", NULL) || elpa_index_get_int_value(index, "gpu", NULL) || elpa_index_get_int_value(index, "amd-gpu", NULL) || elpa_index_get_int_value(index, "intel-gpu", NULL));
-        if ((solver == ELPA_SOLVER_2STAGE) && (gpu_is_active == 1)) {
+        if ( (solver == ELPA_SOLVER_2STAGE) && (gpu_is_active == 1) ) {
                 return ((new_value == 0 ) || (new_value == 1));
         }
         else {
@@ -1286,7 +1309,7 @@ static int use_gpu_id_cardinality(elpa_index_t index) {
 	return 0;
         }
 	return count;
-#elif WITH_AMD_GPU_VERION
+#elif WITH_AMD_GPU_VERSION
 	int count;
 	count = amd_gpu_count();
         if (count == -1000) {
@@ -1294,8 +1317,24 @@ static int use_gpu_id_cardinality(elpa_index_t index) {
 	return 0;
         }
 	return count;
-#elif WITH_INTEL_GPU_VERSION
+//#elif WITH_INTEL_GPU_VERSION
+//	return 0;
+#elif WITH_OPENMP_OFFLOAD_GPU_VERSION
+	int count;
+	count = openmp_offload_gpu_count();
+        if (count == -1000) {
+          fprintf(stderr, "Querrying GPUs failed! Set GPU count = 0\n");
 	return 0;
+        }
+	return count;
+#elif WITH_SYCL_GPU_VERSION
+	int count;
+	count = sycl_gpu_count();
+        if (count == -1000) {
+          fprintf(stderr, "Querrying GPUs failed! Set GPU count = 0\n");
+	return 0;
+        }
+	return count;
 #else
 	return 0;
 #endif
@@ -1326,8 +1365,12 @@ static int use_gpu_id_is_valid(elpa_index_t index, int n, int new_value) {
           return (0 <= new_value) && (new_value <= count);
 	}
 
-#elif WITH_INTEL_GPU_VERSION
-	return 0 == 1;
+//#elif WITH_INTEL_GPU_VERSION
+//	return 0 == 0;
+#elif WITH_OPENMP_OFFLOAD_GPU_VERSION
+	return 0 == 0;
+#elif WITH_SYCL_GPU_VERSION
+	return 0 == 0;
 #else
 	return 0 == 0;
 #endif
