@@ -70,6 +70,7 @@
 #undef  PRECISION_POTRF
 #undef  PRECISION_TRSM
 #undef  PRECISION_GEMV
+#undef  PRECISION_GERC
 #undef  PRECISION_TRMV
 #undef  PRECISION_GEMM
 #undef  PRECISION_TRMM
@@ -108,12 +109,12 @@
 #undef  cublas_PRECISION_GEMV
 #undef  cublas_PRECISION_SYMV
 #undef  cublas_PRECISION_COPY
-#undef  copy_PRECISION_a_tmp1
-#undef  copy_PRECISION_tmp1_tmp2
-#undef  copy_PRECISION_a_tmat2
-#undef  copy_PRECISION_tmp2_tmat2
-#undef  copy_PRECISION_a_tmat1
-#undef  copy_PRECISION_a_tmatc
+#undef  gpu_copy_PRECISION_a_tmp1
+#undef  gpu_copy_PRECISION_tmp1_tmp2
+#undef  gpu_copy_PRECISION_a_tmat2
+#undef  gpu_copy_PRECISION_tmp2_tmat2
+#undef  gpu_copy_PRECISION_a_tmat1
+#undef  gpu_copy_PRECISION_a_tmatc
 #undef  mkl_offload_PRECISION_GEMM
 #undef  mkl_offload_PRECISION_GEMV
 #undef  mkl_offload_PRECISION_TRMM
@@ -158,6 +159,7 @@
 #define  PRECISION_POTRF DPOTRF
 #define  PRECISION_TRSM DTRSM
 #define  PRECISION_GEMV DGEMV
+#define  PRECISION_GERC DGER
 #define  PRECISION_TRMV DTRMV
 #define  PRECISION_GEMM DGEMM
 #define  PRECISION_TRMM DTRMM
@@ -196,12 +198,12 @@
 #define  cublas_PRECISION_GEMV cublas_DGEMV
 #define  cublas_PRECISION_SYMV cublas_DSYMV
 #define  cublas_PRECISION_COPY cublas_DCOPY
-#define  copy_PRECISION_a_tmp1 copy_double_a_tmp1
-#define  copy_PRECISION_tmp1_tmp2 copy_double_tmp1_tmp2
-#define  copy_PRECISION_a_tmat2 copy_double_a_tmat2
-#define  copy_PRECISION_tmp2_tmat2 copy_double_tmp2_tmat2
-#define  copy_PRECISION_a_tmat1 copy_double_a_tmat1
-#define  copy_PRECISION_a_tmatc copy_double_a_tmatc
+#define  gpu_copy_PRECISION_a_tmp1 gpu_copy_double_a_tmp1
+#define  gpu_copy_PRECISION_tmp1_tmp2 gpu_copy_double_tmp1_tmp2
+#define  gpu_copy_PRECISION_a_tmat2 gpu_copy_double_a_tmat2
+#define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_double_tmp2_tmat2
+#define  gpu_copy_PRECISION_a_tmat1 gpu_copy_double_a_tmat1
+#define  gpu_copy_PRECISION_a_tmatc gpu_copy_double_a_tmatc
 #define  mkl_offload_PRECISION_GEMM mkl_offload_DGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_DGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_DTRMM
@@ -243,6 +245,7 @@
 #define  PRECISION_POTRF SPOTRF
 #define  PRECISION_TRSM STRSM
 #define  PRECISION_GEMV SGEMV
+#define  PRECISION_GERC SGER
 #define  PRECISION_TRMV STRMV
 #define  PRECISION_GEMM SGEMM
 #define  PRECISION_TRMM STRMM
@@ -281,12 +284,12 @@
 #define  cublas_PRECISION_GEMV cublas_SGEMV
 #define  cublas_PRECISION_SYMV cublas_SSYMV
 #define  cublas_PRECISION_COPY cublas_SCOPY
-#define  copy_PRECISION_a_tmp1 copy_float_a_tmp1
-#define  copy_PRECISION_tmp1_tmp2 copy_float_tmp1_tmp2
-#define  copy_PRECISION_a_tmat2 copy_float_a_tmat2
-#define  copy_PRECISION_tmp2_tmat2 copy_float_tmp2_tmat2
-#define  copy_PRECISION_a_tmat1 copy_float_a_tmat1
-#define  copy_PRECISION_a_tmatc copy_float_a_tmatc
+#define  gpu_copy_PRECISION_a_tmp1 gpu_copy_float_a_tmp1
+#define  gpu_copy_PRECISION_tmp1_tmp2 gpu_copy_float_tmp1_tmp2
+#define  gpu_copy_PRECISION_a_tmat2 gpu_copy_float_a_tmat2
+#define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_float_tmp2_tmat2
+#define  gpu_copy_PRECISION_a_tmat1 gpu_copy_float_a_tmat1
+#define  gpu_copy_PRECISION_a_tmatc gpu_copy_float_a_tmatc
 #define  mkl_offload_PRECISION_GEMM mkl_offload_SGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_SGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_STRMM
@@ -341,6 +344,7 @@
 #undef  PRECISION_TRSM
 #undef  PRECISION_STR
 #undef  PRECISION_GEMV
+#undef  PRECISION_GERC
 #undef  PRECISION_TRMV
 #undef  PRECISION_GEMM
 #undef  PRECISION_TRMM
@@ -377,12 +381,12 @@
 #undef  cublas_PRECISION_GEMV
 #undef  cublas_PRECISION_SYMV
 #undef  cublas_PRECISION_COPY
-#undef  copy_PRECISION_a_tmp1
-#undef  copy_PRECISION_tmp1_tmp2
-#undef  copy_PRECISION_a_tmat2
-#undef  copy_PRECISION_tmp2_tmat2
-#undef  copy_PRECISION_a_tmat1
-#undef  copy_PRECISION_a_tmatc
+#undef  gpu_copy_PRECISION_a_tmp1
+#undef  gpu_copy_PRECISION_tmp1_tmp2
+#undef  gpu_copy_PRECISION_a_tmat2
+#undef  gpu_copy_PRECISION_tmp2_tmat2
+#undef  gpu_copy_PRECISION_a_tmat1
+#undef  gpu_copy_PRECISION_a_tmatc
 #undef  gpusolver_PRECISION_TRTRI
 #undef  gpusolver_PRECISION_POTRF
 #undef  mkl_offload_PRECISION_GEMM 
@@ -439,6 +443,7 @@
 #define  PRECISION_POTRF ZPOTRF
 #define  PRECISION_TRSM ZTRSM
 #define  PRECISION_GEMV ZGEMV
+#define  PRECISION_GERC ZGERC
 #define  PRECISION_TRMV ZTRMV
 #define  PRECISION_GEMM ZGEMM
 #define  PRECISION_TRMM ZTRMM
@@ -477,12 +482,12 @@
 #define  cublas_PRECISION_GEMV cublas_ZGEMV
 #define  cublas_PRECISION_SYMV cublas_ZSYMV
 #define  cublas_PRECISION_COPY cublas_ZCOPY
-#define  copy_PRECISION_a_tmp1 copy_double_complex_a_tmp1
-#define  copy_PRECISION_tmp1_tmp2 copy_double_complex_tmp1_tmp2
-#define  copy_PRECISION_a_tmat2 copy_double_complex_a_tmat2
-#define  copy_PRECISION_tmp2_tmat2 copy_double_complex_tmp2_tmat2
-#define  copy_PRECISION_a_tmat1 copy_double_complex_a_tmat1
-#define  copy_PRECISION_a_tmatc copy_double_complex_a_tmatc
+#define  gpu_copy_PRECISION_a_tmp1 gpu_copy_double_complex_a_tmp1
+#define  gpu_copy_PRECISION_tmp1_tmp2 gpu_copy_double_complex_tmp1_tmp2
+#define  gpu_copy_PRECISION_a_tmat2 gpu_copy_double_complex_a_tmat2
+#define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_double_complex_tmp2_tmat2
+#define  gpu_copy_PRECISION_a_tmat1 gpu_copy_double_complex_a_tmat1
+#define  gpu_copy_PRECISION_a_tmatc gpu_copy_double_complex_a_tmatc
 #define  mkl_offload_PRECISION_GEMM mkl_offload_ZGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_ZGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_ZTRMM
@@ -528,6 +533,7 @@
 #define  PRECISION_POTRF CPOTRF
 #define  PRECISION_TRSM CTRSM
 #define  PRECISION_GEMV CGEMV
+#define  PRECISION_GERC CGERC
 #define  PRECISION_TRMV CTRMV
 #define  PRECISION_GEMM CGEMM
 #define  PRECISION_TRMM CTRMM
@@ -566,12 +572,12 @@
 #define  cublas_PRECISION_GEMV cublas_CGEMV
 #define  cublas_PRECISION_SYMV cublas_CSYMV
 #define  cublas_PRECISION_COPY cublas_CCOPY
-#define  copy_PRECISION_a_tmp1 copy_float_complex_a_tmp1
-#define  copy_PRECISION_tmp1_tmp2 copy_float_complex_tmp1_tmp2
-#define  copy_PRECISION_a_tmat2 copy_float_complex_a_tmat2
-#define  copy_PRECISION_tmp2_tmat2 copy_float_complex_tmp2_tmat2
-#define  copy_PRECISION_a_tmat1 copy_float_complex_a_tmat1
-#define  copy_PRECISION_a_tmatc copy_float_complex_a_tmatc
+#define  gpu_copy_PRECISION_a_tmp1 gpu_copy_float_complex_a_tmp1
+#define  gpu_copy_PRECISION_tmp1_tmp2 gpu_copy_float_complex_tmp1_tmp2
+#define  gpu_copy_PRECISION_a_tmat2 gpu_copy_float_complex_a_tmat2
+#define  gpu_copy_PRECISION_tmp2_tmat2 gpu_copy_float_complex_tmp2_tmat2
+#define  gpu_copy_PRECISION_a_tmat1 gpu_copy_float_complex_a_tmat1
+#define  gpu_copy_PRECISION_a_tmatc gpu_copy_float_complex_a_tmatc
 #define  mkl_offload_PRECISION_GEMM mkl_offload_CGEMM
 #define  mkl_offload_PRECISION_GEMV mkl_offload_CGEMV
 #define  mkl_offload_PRECISION_TRMM mkl_offload_CTRMM
